<script setup lang="ts">
import TitlePanel from "@/views/ecg/doctor/components/TitlePanel.vue";
import QueuePanel from "@/views/ecg/doctor/components/QueuePanel.vue";
import {DoctorApi, PatientStatisticVO, RoomBedVO} from '@/api/ecg/doctor';
import {useUserStore} from "@/store/modules/user";
import {QueueVO} from "@/api/ecg/queue";

const userStore = useUserStore();

const roomBedVO: RoomBedVO = {
    roomId: userStore.room!.roomId,
    bedNo: userStore.room!.bedNo
}

const patientStat = ref<PatientStatisticVO>({
    finishedNum: 0,
    readyNum: 0,
    passedNum: 0,
    queuingNum: 0
})

const state = ref<boolean>()

const list = ref<QueueVO[]>([])

let timerRunFlag : boolean = false
const bedControlFlag = ref<boolean>(true);
const finishFlag = ref<boolean>(true);
const passFlag = ref<boolean>(true);

const finishNextPatient = async () => {
  finishFlag.value = true
  list.value = await DoctorApi.finishNextPatient(roomBedVO)
  patientStat.value = await DoctorApi.getPatientStatistic(roomBedVO)
  finishFlag.value = false
}

const passNextPatient = async () => {
  passFlag.value = true
  list.value = await DoctorApi.passNextPatient(roomBedVO)
  patientStat.value = await DoctorApi.getPatientStatistic(roomBedVO)
  passFlag.value = false
}

const initLoad = async () => {
  list.value = await DoctorApi.getPatientList(roomBedVO)
  patientStat.value = await DoctorApi.getPatientStatistic(roomBedVO)
  const queueVO2 = await DoctorApi.bedDoctorGet(roomBedVO)
  if (queueVO2.status === 20)
    state.value = true
  else if (queueVO2.status === 30)
    state.value = false
}

const bedControl = async () => {
  bedControlFlag.value = true
  if (state.value) {
    await DoctorApi.bedDoctorPause(roomBedVO)
    state.value = false
  } else {
    await DoctorApi.bedDoctorResume(roomBedVO)
    state.value = true
  }
  bedControlFlag.value = false
}

const doctorTimer = () => {
  console.log('doctor ...')
  initLoad()
  if (timerRunFlag)
    setTimeout(doctorTimer, 5000) // five seconds
}

/** 初始化 **/
onMounted(() => {
  console.info("onMounted - doctor")
  bedControlFlag.value = true
  finishFlag.value = true
  passFlag.value = true

  timerRunFlag = true
  doctorTimer()

  bedControlFlag.value = false
  finishFlag.value = false
  passFlag.value = false
})

onUnmounted( () =>{
  console.info("onUnmounted - doctor")
  timerRunFlag = false
})

</script>

<template>
  <el-container>
    <el-header style="background-color: var(--el-color-primary-light-7); font-size: 24px">
      <TitlePanel :patientStatistic="patientStat" />
    </el-header>
    <el-container>
      <el-main>
        装机界面
      </el-main>
      <el-aside width="300px" style="background-color: var(--el-color-primary-light-7);">
        <QueuePanel :queue="list"/>
      </el-aside>
    </el-container>
    <el-container style="justify-content: center; margin-top: 30px">
      <el-button :disabled="finishFlag" type="primary" @click="finishNextPatient">叫号</el-button>
      <el-button :disabled="passFlag" type="primary" @click="passNextPatient">过号</el-button>
      <el-button :disabled="bedControlFlag" type="primary" @click="bedControl">{{state?'暂停':'恢复'}}</el-button>
    </el-container>
  </el-container>
</template>

<style scoped lang="scss">

</style>
